@@ -16,7 +16,7 @@ from acp.client.protocol import (
     BaseClient,
     Client,
     ExtensibilityCapability,
-    FileSystemCapability,
+    FsCapability,
     TerminalCapability,
 )
 from acp.terminal_handle import TerminalHandle
@@ -25,6 +25,18 @@ from acp.schema import (
     AuthenticateResponse,
     CancelNotification,
     CreateTerminalRequest,
+    ClientCapabilities,
+    SessionMode,
+    FileSystemCapability,
+    AgentMessageChunk,
+    UserMessageChunk,
+    TextContentBlock,
+    SessionModeState,
+    Implementation,
+    EnvVariable,
+    StdioMcpServer,
+    SseMcpServer,
+    HttpMcpServer,
     CreateTerminalResponse,
     InitializeRequest,
     InitializeResponse,
@@ -73,13 +85,25 @@ __all__ = [  # noqa: RUF022
     # types
     "InitializeRequest",
     "InitializeResponse",
+    "EnvVariable",
+    "HttpMcpServer",
+    "StdioMcpServer",
+    "SseMcpServer",
     "NewSessionRequest",
+    "AgentMessageChunk",
+    "FsCapability",
+    "UserMessageChunk",
+    "TextContentBlock",
     "NewSessionResponse",
     "LoadSessionRequest",
     "LoadSessionResponse",
     "AuthenticateRequest",
     "AuthenticateResponse",
     "PromptRequest",
+    "ClientCapabilities",
+    "SessionModeState",
+    "SessionMode",
+    "Implementation",
     "PromptResponse",
     "WriteTextFileRequest",
     "WriteTextFileResponse",
