@@ -5,18 +5,15 @@ from __future__ import annotations
 from collections import deque
 from contextlib import asynccontextmanager
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, Literal, Self, overload
+from typing import TYPE_CHECKING, Any, Self, overload
 from uuid import UUID, uuid4
 
-from llmling import BasePrompt, PromptMessage, StaticPrompt
-from llmling.config.models import BaseResource
+from llmling import BasePrompt
 from psygnal import Signal
-from pydantic_ai import UserPromptPart
 from upathtools import read_path
 
 from llmling_agent.log import get_logger
-from llmling_agent.messaging.message_container import ChatMessageContainer
-from llmling_agent.messaging.messages import ChatMessage
+from llmling_agent.messaging import ChatMessage, ChatMessageContainer
 from llmling_agent.utils.count_tokens import count_tokens
 from llmling_agent.utils.now import get_now
 from llmling_agent_config.session import SessionQuery
@@ -38,19 +35,6 @@ if TYPE_CHECKING:
 
 logger = get_logger(__name__)
 
-OverrideMode = Literal["replace", "append"]
-type PromptInput = str | BasePrompt
-
-
-def _to_base_prompt(prompt: PromptInput) -> BasePrompt:
-    """Convert input to BasePrompt instance."""
-    if isinstance(prompt, str):
-        msg = PromptMessage(role="system", content=prompt)
-        return StaticPrompt(
-            name="System prompt", description="System prompt", messages=[msg]
-        )
-    return prompt
-
 
 class ConversationManager:
     """Manages conversation state and system prompts."""
@@ -232,8 +216,6 @@ class ConversationManager:
             match source:
                 case str():
                     await self.add_context_from_path(source)
-                case BaseResource():
-                    await self.add_context_from_resource(source)
                 case BasePrompt():
                     await self.add_context_from_prompt(source)
         except Exception:
@@ -386,11 +368,7 @@ class ConversationManager:
                     messages = await self._agent.context.storage.filter_messages(history)
                 else:
                     messages = [
-                        ChatMessage(
-                            content=prompt,
-                            role="user",
-                            parts=[UserPromptPart(content=prompt)],
-                        )
+                        ChatMessage.user_prompt(message=prompt)
                         for p in history
                         if (prompt := await to_prompt(p))
                     ]
@@ -440,7 +418,6 @@ class ConversationManager:
             content=formatted,
             role="user",
             name="user",
-            model_name=self._agent.model_name,
             metadata=metadata,
             conversation_id="context",  # TODO: should probably allow DB field to be NULL
         )
@@ -476,30 +453,6 @@ class ConversationManager:
             source = f"{path_obj.protocol}:{path_obj.name}"
         self.add_context_message(content, source=source, **metadata)
 
-    async def add_context_from_resource(self, resource: Resource | str):
-        """Add content from a LLMling resource."""
-        if not self._agent.runtime:
-            msg = "No runtime available"
-            raise RuntimeError(msg)
-
-        if isinstance(resource, str):
-            content = await self._agent.runtime.load_resource(resource)
-            self.add_context_message(
-                str(content.content),
-                source=f"Resource {resource}",
-                mime_type=content.metadata.mime_type,
-                **content.metadata.extra,
-            )
-        else:
-            loader = self._agent.runtime._loader_registry.get_loader(resource)
-            async for content in loader.load(resource):
-                self.add_context_message(
-                    str(content.content),
-                    source=f"{resource.type}:{resource.uri}",
-                    mime_type=content.metadata.mime_type,
-                    **content.metadata.extra,
-                )
-
     async def add_context_from_prompt(
         self,
         prompt: PromptType,
