@@ -6,10 +6,11 @@ from collections.abc import Awaitable, Callable
 from typing import Any, ClassVar, Literal, get_args, get_origin
 from uuid import UUID
 
-from llmling import LLMCallableTool
 from pydantic import BaseModel, ConfigDict, field_validator
 from pydantic_ai import AgentStreamEvent, RunContext
 from pydantic_ai.models import Model
+from toprompt.to_prompt import AnyPromptType
+from upath.types import JoinablePathLike
 
 
 # Define what we consider JSON-serializable
@@ -23,6 +24,7 @@ SimpleJsonType = dict[
     str, bool | int | float | str | list[str] | dict[str, bool | int | float | str]
 ]
 type SessionIdType = str | UUID | None
+type ProcessorCallback[TResult] = Callable[..., TResult | Awaitable[TResult]]
 
 
 NodeName = str
@@ -32,7 +34,7 @@ MessageRole = Literal["user", "assistant"]
 PartType = Literal["text", "image", "audio", "video"]
 ModelType = Model | str | None
 EnvironmentType = Literal["file", "inline"]
-ToolSource = Literal["runtime", "agent", "builtin", "dynamic", "task", "mcp", "toolset"]
+ToolSource = Literal["agent", "builtin", "dynamic", "task", "mcp", "toolset"]
 AnyCallable = Callable[..., Any]
 AsyncFilterFn = Callable[..., Awaitable[bool]]
 SyncFilterFn = Callable[..., bool]
@@ -40,12 +42,12 @@ AnyFilterFn = Callable[..., bool | Awaitable[bool]]
 type AnyTransformFn[T] = Callable[[T], T | Awaitable[T]]
 type OptionalAwaitable[T] = T | Awaitable[T]
 
-type ToolType = str | AnyCallable | LLMCallableTool
+type ToolType = str | AnyCallable
 
 # Event handler types for composable event processing
 # Individual event handler for composability - takes single events
 IndividualEventHandler = Callable[[RunContext, AgentStreamEvent], Awaitable[None]]
-
+PromptCompatible = AnyPromptType | JoinablePathLike
 # P = ParamSpec("P")
 # SyncAsync = Callable[P, OptionalAwaitable[T]]
 EndStrategy = Literal["early", "exhaustive"]
