@@ -11,8 +11,8 @@ from typing import TYPE_CHECKING, Any, Literal, Self, overload
 from psygnal.containers import EventedList
 
 from llmling_agent.log import get_logger
+from llmling_agent.messaging import MessageNode
 from llmling_agent.messaging.context import NodeContext
-from llmling_agent.messaging.messagenode import MessageNode
 from llmling_agent.models.manifest import AgentsManifest
 from llmling_agent.talk.stats import AggregatedMessageStats
 from llmling_agent.tools.base import Tool
@@ -21,21 +21,22 @@ from llmling_agent_config.teams import TeamConfig
 
 if TYPE_CHECKING:
     from collections.abc import AsyncIterator, Iterator, Sequence
-    import os
 
-    import PIL.Image
     from psygnal.containers._evented_list import ListEvents
     from toprompt import AnyPromptType
 
     from llmling_agent import Agent, AgentPool, Team
-    from llmling_agent.common_types import ModelType, ToolType
+    from llmling_agent.common_types import (
+        ModelType,
+        ProcessorCallback,
+        PromptCompatible,
+        ToolType,
+    )
     from llmling_agent.delegation.teamrun import ExtendedTeamTalk, TeamRun
-    from llmling_agent.messaging.messages import ChatMessage, TeamResponse
+    from llmling_agent.messaging import ChatMessage, TeamResponse
     from llmling_agent.talk.stats import AggregatedTalkStats
     from llmling_agent_config.mcp_server import MCPServerConfig
-    from llmling_agent_config.providers import ProcessorCallback
     from llmling_agent_config.session import SessionQuery
-    from llmling_agent_providers.base import AgentProvider
 
 logger = get_logger(__name__)
 
@@ -162,10 +163,6 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
         if isinstance(node, Agent):
             node.tools.add_provider(self.mcp)
-        # TODO: Right now connecting here is not desired since emission means db logging
-        # ideally db logging would not rely on the "public" agent signal.
-
-        # node.tool_used.connect(self.tool_used)
 
     def _on_node_removed(self, index: int, node: MessageNode[Any, Any]):
         """Handler for removing nodes from the team."""
@@ -173,7 +170,6 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
         if isinstance(node, Agent):
             node.tools.remove_provider(self.mcp)
-        # node.tool_used.disconnect(self.tool_used)
 
     def __repr__(self) -> str:
         """Create readable representation."""
@@ -290,7 +286,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
     async def run_in_background(
         self,
-        *prompts: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None,
+        *prompts: PromptCompatible | None,
         max_count: int | None = 1,  # 1 = single execution, None = indefinite
         interval: float = 1.0,
         **kwargs: Any,
@@ -472,7 +468,6 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         replace_history: bool = False,
         pause_routing: bool = False,
         model: ModelType | None = None,
-        provider: AgentProvider | None = None,
     ) -> AsyncIterator[Self]:
         """Temporarily modify state of all agents in the team.
 
@@ -487,7 +482,6 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
             replace_history: Whether to replace existing history
             pause_routing: Whether to pause message routing
             model: Temporary model override
-            provider: Temporary provider override
         """
         # Get all agents (flattened) before entering context
         agents = list(self.iter_agents())
@@ -507,7 +501,6 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
                         replace_history=replace_history,
                         pause_routing=pause_routing,
                         model=model,
-                        provider=provider,
                     )
                 )
             try:
@@ -519,27 +512,10 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
     @abstractmethod
     async def execute(
         self,
-        *prompts: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None,
+        *prompts: PromptCompatible | None,
         **kwargs: Any,
     ) -> TeamResponse: ...
 
-    def run_sync(
-        self,
-        *prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str],
-        store_history: bool = True,
-    ) -> ChatMessage[TResult]:
-        """Run agent synchronously (convenience wrapper).
-
-        Args:
-            prompt: User query or instruction
-            store_history: Whether the message exchange should be added to the
-                           context window
-        Returns:
-            Result containing response and run information
-        """
-        coro = self.run(*prompt, store_history=store_history)
-        return self.task_manager.run_task_sync(coro)
-
 
 if __name__ == "__main__":
 
