@@ -3,12 +3,12 @@
 from __future__ import annotations
 
 import asyncio
+from asyncio import Lock
 from contextlib import AsyncExitStack, asynccontextmanager, suppress
 import os
 from typing import TYPE_CHECKING, Any, Self, Unpack, cast, overload
 
 from anyenv import MultiEventHandler
-from llmling import BaseRegistry, LLMLingError
 from upath import UPath
 
 from llmling_agent.agent import Agent
@@ -17,11 +17,12 @@ from llmling_agent.delegation.message_flow_tracker import MessageFlowTracker
 from llmling_agent.delegation.team import Team
 from llmling_agent.delegation.teamrun import TeamRun
 from llmling_agent.log import get_logger
+from llmling_agent.messaging import MessageEmitter
 from llmling_agent.messaging.context import ProgressCallback
-from llmling_agent.messaging.messageemitter import MessageEmitter
 from llmling_agent.talk import Talk, TeamTalk
 from llmling_agent.talk.registry import ConnectionRegistry
 from llmling_agent.tasks import TaskRegistry
+from llmling_agent.utils.baseregistry import BaseRegistry
 from llmling_agent_config.forward_targets import (
     CallableConnectionConfig,
     FileConnectionConfig,
@@ -127,20 +128,8 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
         self.process_manager = ProcessManager()
         self.pool_talk = TeamTalk[Any].from_nodes(list(self.nodes.values()))
-        if self.manifest.pool_server and self.manifest.pool_server.enabled:
-            from llmling_agent.resource_providers.pool import PoolResourceProvider
-            from llmling_agent_mcp.server import LLMLingServer
-
-            provider = PoolResourceProvider(
-                self, zed_mode=self.manifest.pool_server.zed_mode
-            )
-            self.server: LLMLingServer | None = LLMLingServer(
-                provider=provider,
-                config=self.manifest.pool_server,
-            )
-            self.progress_handlers.add_handler(self.server.report_progress)
-        else:
-            self.server = None
+        # MCP server is now managed externally
+        self.server = None
         # Create requested agents immediately
         for name in self.manifest.agents:
             agent = self.manifest.get_agent(name, deps=shared_deps)
@@ -154,40 +143,45 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         if connect_nodes:
             self._connect_nodes()
 
+        # Initialize async safety fields
+        self._enter_lock = Lock()
+        self._running_count = 0
+
     async def __aenter__(self) -> Self:
         """Enter async context and initialize all agents."""
-        try:
-            # Add MCP tool provider to all agents
-            agents = list(self.agents.values())
-            teams = list(self.teams.values())
-            for agent in agents:
-                agent.tools.add_provider(self.mcp)
+        async with self._enter_lock:
+            if self._running_count == 0:
+                try:
+                    # Add MCP tool provider to all agents
+                    agents = list(self.agents.values())
+                    teams = list(self.teams.values())
+                    for agent in agents:
+                        agent.tools.add_provider(self.mcp)
 
-            # Collect all components to initialize
-            components: list[AbstractAsyncContextManager[Any]] = [
-                self.mcp,
-                *agents,
-                *teams,
-            ]
+                    # Collect all components to initialize
+                    components: list[AbstractAsyncContextManager[Any]] = [
+                        self.mcp,
+                        self.storage,
+                        *agents,
+                        *teams,
+                    ]
 
-            # Add MCP server if configured
-            if self.server:
-                components.append(self.server)
-            components.append(self.storage)
-            # Initialize all components
-            if self.parallel_load:
-                await asyncio.gather(
-                    *(self.exit_stack.enter_async_context(c) for c in components)
-                )
-            else:
-                for component in components:
-                    await self.exit_stack.enter_async_context(component)
+                    # MCP server is now managed externally - removed from pool
+                    # Initialize all components
+                    if self.parallel_load:
+                        await asyncio.gather(
+                            *(self.exit_stack.enter_async_context(c) for c in components)
+                        )
+                    else:
+                        for component in components:
+                            await self.exit_stack.enter_async_context(component)
 
-        except Exception as e:
-            await self.cleanup()
-            msg = "Failed to initialize agent pool"
-            logger.exception(msg, exc_info=e)
-            raise RuntimeError(msg) from e
+                except Exception as e:
+                    await self.cleanup()
+                    msg = "Failed to initialize agent pool"
+                    logger.exception(msg, exc_info=e)
+                    raise RuntimeError(msg) from e
+            self._running_count += 1
         return self
 
     async def __aexit__(
@@ -197,11 +191,22 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         exc_tb: TracebackType | None,
     ):
         """Exit async context."""
-        # Remove MCP tool provider from all agents
-        for agent in self.agents.values():
-            if self.mcp in agent.tools.providers:
-                agent.tools.remove_provider(self.mcp)
-        await self.cleanup()
+        if self._running_count == 0:
+            msg = "AgentPool.__aexit__ called more times than __aenter__"
+            raise ValueError(msg)
+        async with self._enter_lock:
+            self._running_count -= 1
+            if self._running_count == 0:
+                # Remove MCP tool provider from all agents
+                for agent in self.agents.values():
+                    if self.mcp in agent.tools.providers:
+                        agent.tools.remove_provider(self.mcp)
+                await self.cleanup()
+
+    @property
+    def is_running(self) -> bool:
+        """Check if the agent pool is running."""
+        return bool(self._running_count)
 
     async def cleanup(self):
         """Clean up all agents."""
@@ -422,11 +427,6 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         """Get node events."""
         return self._items.events
 
-    @property
-    def _error_class(self) -> type[LLMLingError]:
-        """Error class for agent operations."""
-        return LLMLingError
-
     def _validate_item(
         self, item: MessageEmitter[Any, Any] | Any
     ) -> MessageEmitter[Any, Any]:
@@ -489,8 +489,11 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                             msg = f"Forward target {name_} not found for {name}"
                             raise ValueError(msg)
                         target_node = self[name_]
-                    case FileConnectionConfig() | CallableConnectionConfig():
-                        target_node = Agent(provider=target.get_provider())
+                    case FileConnectionConfig(path=path_obj):
+                        name = f"file_writer_{UPath(path_obj).stem}"
+                        target_node = Agent(model=target.get_model(), name=name)
+                    case CallableConnectionConfig(callable=fn):
+                        target_node = Agent(model=target.get_model(), name=fn.__name__)
                     case _:
                         msg = f"Invalid connection config: {target}"
                         raise ValueError(msg)
@@ -652,7 +655,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         agent = self.manifest.get_agent(name, deps=final_deps)
         # Override name if requested
         if name_override:
-            agent.name = name_override
+            agent._name = name_override
 
         # Set pool reference
         agent.context.pool = self
@@ -665,7 +668,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         agent = await self.exit_stack.enter_async_context(agent)
 
         # Override structured configuration if provided
-        if return_type is not None:
+        if return_type not in {None, str}:
             agent.set_output_type(return_type)
 
         return agent
@@ -689,41 +692,22 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                 raise ValueError(msg) from e
 
     @overload
-    def get_agent(
+    def get_agent[TResult = str](
         self,
         agent: AgentName | Agent[Any, str],
         *,
-        model_override: str | None = None,
-        session: SessionIdType | SessionQuery = None,
-    ) -> Agent[TPoolDeps]: ...
-
-    @overload
-    def get_agent[TResult](
-        self,
-        agent: AgentName | Agent[Any, str],
-        *,
-        return_type: type[TResult],
+        return_type: type[TResult] = str,  # type: ignore
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
     ) -> Agent[TPoolDeps, TResult]: ...
 
     @overload
-    def get_agent[TCustomDeps](
+    def get_agent[TCustomDeps, TResult = str](
         self,
         agent: AgentName | Agent[Any, str],
         *,
-        deps: TCustomDeps,
-        model_override: str | None = None,
-        session: SessionIdType | SessionQuery = None,
-    ) -> Agent[TCustomDeps]: ...
-
-    @overload
-    def get_agent[TCustomDeps, TResult](
-        self,
-        agent: AgentName | Agent[Any, str],
-        *,
-        deps: TCustomDeps,
-        return_type: type[TResult],
+        deps_type: type[TCustomDeps],
+        return_type: type[TResult] = str,  # type: ignore
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
     ) -> Agent[TCustomDeps, TResult]: ...
@@ -732,8 +716,8 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         self,
         agent: AgentName | Agent[Any, str],
         *,
-        deps: Any | None = None,
-        return_type: Any | None = None,
+        deps_type: Any | None = None,
+        return_type: Any = str,
         model_override: str | None = None,
         session: SessionIdType | SessionQuery = None,
     ) -> Agent[Any, Any]:
@@ -745,7 +729,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
         Args:
             agent: Either agent name or instance
-            deps: Optional custom dependencies (overrides shared deps)
+            deps_type: Optional custom dependencies type (overrides shared deps)
             return_type: Optional type for structured responses
             model_override: Optional model override
             session: Optional session ID or query to recover conversation
@@ -770,7 +754,8 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             base.context = AgentContext[Any].create_default(base.name)
 
         # Use custom deps if provided, otherwise use shared deps
-        base.context.data = deps if deps is not None else self.shared_deps
+        # base.context.data = deps if deps is not None else self.shared_deps
+        base.deps_type = deps_type
         base.context.pool = self
 
         # Apply overrides
@@ -781,7 +766,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             base.conversation.load_history_from_database(session=session)
 
         # Convert to structured if needed
-        if return_type is not None:
+        if return_type not in {str, None}:
             base.set_output_type(return_type)
 
         return base
@@ -868,8 +853,8 @@ if __name__ == "__main__":
 
     async def main():
         path = "src/llmling_agent/config_resources/agents.yml"
-        async with AgentPool[None](path) as pool:
-            agent: Agent[None, Any] = pool.get_agent("overseer")
+        async with AgentPool(path) as pool:
+            agent = pool.get_agent("overseer")
             print(agent)
 
     import asyncio
