@@ -12,7 +12,7 @@ from toprompt import to_prompt
 
 from llmling_agent.delegation.base_team import BaseTeam
 from llmling_agent.log import get_logger
-from llmling_agent.messaging.messages import AgentResponse, ChatMessage, TeamResponse
+from llmling_agent.messaging import AgentResponse, ChatMessage, TeamResponse
 from llmling_agent.utils.now import get_now
 
 
@@ -20,14 +20,13 @@ logger = get_logger(__name__)
 
 if TYPE_CHECKING:
     from collections.abc import AsyncIterator
-    import os
 
-    import PIL.Image
     from pydantic_ai import AgentStreamEvent
     from toprompt import AnyPromptType
 
     from llmling_agent import MessageNode
-    from llmling_agent.agent.agent import StreamCompleteEvent
+    from llmling_agent.agent.events import StreamCompleteEvent
+    from llmling_agent.common_types import PromptCompatible
     from llmling_agent.talk import Talk
     from llmling_agent_config.task import Job
 
@@ -67,7 +66,7 @@ class Team[TDeps = None](BaseTeam[TDeps, Any]):
 
     async def execute(
         self,
-        *prompts: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None,
+        *prompts: PromptCompatible | None,
         **kwargs: Any,
     ) -> TeamResponse:
         """Run all agents in parallel with monitoring."""
@@ -170,7 +169,7 @@ class Team[TDeps = None](BaseTeam[TDeps, Any]):
 
     async def _run(
         self,
-        *prompts: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None,
+        *prompts: PromptCompatible | None,
         wait_for_connections: bool | None = None,
         message_id: str | None = None,
         conversation_id: str | None = None,
@@ -181,6 +180,7 @@ class Team[TDeps = None](BaseTeam[TDeps, Any]):
         message_id = message_id or str(uuid4())
         return ChatMessage(
             content=[r.message.content for r in result if r.message],
+            messages=[m for r in result if r.message for m in r.message.messages],
             role="assistant",
             name=self.name,
             message_id=message_id,
@@ -194,7 +194,7 @@ class Team[TDeps = None](BaseTeam[TDeps, Any]):
 
     async def run_stream(
         self,
-        *prompts: AnyPromptType | PIL.Image.Image | os.PathLike[str],
+        *prompts: PromptCompatible,
         **kwargs: Any,
     ) -> AsyncIterator[
         tuple[MessageNode[Any, Any], AgentStreamEvent | StreamCompleteEvent]
@@ -284,7 +284,7 @@ class Team[TDeps = None](BaseTeam[TDeps, Any]):
                         start = perf_counter()
                         resp = AgentResponse(
                             agent_name=agent.name,
-                            message=await agent.run(prompt, store_history=store_history),  # pyright: ignore
+                            message=await agent.run(prompt, store_history=store_history),
                             timing=perf_counter() - start,
                         )
                         responses.append(resp)
