@@ -35,6 +35,13 @@ from llmling_agent.mcp_server.helpers import (
     extract_tool_call_args,
     mcp_tool_to_fn_schema,
 )
+from llmling_agent.mcp_server.message_handler import MCPMessageHandler
+from llmling_agent.tools.base import Tool
+from llmling_agent_config.mcp_server import (
+    SSEMCPServerConfig,
+    StdioMCPServerConfig,
+    StreamableHTTPMCPServerConfig,
+)
 
 
 type ContextualProgressHandler = Callable[
@@ -49,7 +56,9 @@ type ContextualProgressHandler = Callable[
     Any,  # Supports both sync (None) and async (Awaitable[None]) returns
 ]
 
+
 if TYPE_CHECKING:
+    from collections.abc import Sequence
     from types import TracebackType
 
     from fastmcp.client import ClientTransport
@@ -61,15 +70,17 @@ if TYPE_CHECKING:
     import mcp
     from mcp.client.session import RequestContext
     from mcp.types import (
+        BlobResourceContents,
+        ContentBlock,
         CreateMessageRequestParams,
         ElicitRequestParams,
         Prompt as MCPPrompt,
         Resource as MCPResource,
         SamplingMessage,
+        TextResourceContents,
         Tool as MCPTool,
     )
 
-    from llmling_agent.tools.base import Tool
     from llmling_agent_config.mcp_server import MCPServerConfig
 
 
@@ -204,12 +215,6 @@ class MCPClient:
         from fastmcp.client import SSETransport, StreamableHttpTransport
         from fastmcp.client.transports import StdioTransport
 
-        from llmling_agent_config.mcp_server import (
-            SSEMCPServerConfig,
-            StdioMCPServerConfig,
-            StreamableHTTPMCPServerConfig,
-        )
-
         transport: ClientTransport
         # Create transport based on config type
         match config:
@@ -233,14 +238,7 @@ class MCPClient:
                 raise ValueError(msg)
 
         # Create message handler if needed
-        msg_handler: MessageHandlerT | MessageHandler | None
-        if not self._message_handler:
-            from llmling_agent.mcp_server.message_handler import MCPMessageHandler
-
-            msg_handler = MCPMessageHandler(self)
-        else:
-            msg_handler = self._message_handler
-
+        msg_handler = self._message_handler or MCPMessageHandler(self)
         return fastmcp.Client(
             transport,
             log_handler=self._log_handler,
@@ -312,8 +310,6 @@ class MCPClient:
 
     def convert_tool(self, tool: MCPTool) -> Tool:
         """Create a properly typed callable from MCP tool schema."""
-        from llmling_agent import Tool
-
         schema = mcp_tool_to_fn_schema(tool)
         fn_schema = FunctionSchema.from_dict(schema)
         sig = fn_schema.to_python_signature()
@@ -323,18 +319,15 @@ class MCPClient:
             # Filter out None values for optional params
             schema_props = tool.inputSchema.get("properties", {})
             required_props = set(tool.inputSchema.get("required", []))
-
             filtered_kwargs = {
                 k: v
                 for k, v in kwargs.items()
                 if k in required_props or (k in schema_props and v is not None)
             }
-            tc_id = ctx.tool_call_id if ctx else None
-
             return await self.call_tool(
                 tool.name,
                 filtered_kwargs,
-                tool_call_id=tc_id,
+                tool_call_id=ctx.tool_call_id if ctx else None,
                 run_context=ctx,
             )
 
@@ -344,11 +337,9 @@ class MCPClient:
         # Update return annotation to support multiple types
         annotations["return"] = str | Any | ToolReturn
         tool_callable.__annotations__ = annotations
-
         tool_callable.__name__ = tool.name
         tool_callable.__doc__ = tool.description or "No description provided."
-        meta = {"mcp_tool": tool.name}
-        return Tool.from_callable(tool_callable, source="mcp", metadata=meta)
+        return Tool.from_callable(tool_callable, source="mcp")
 
     def _create_final_progress_handler(
         self, tool_name: str, tool_call_id: str, tool_input: dict[str, Any]
@@ -415,7 +406,10 @@ class MCPClient:
             msg = f"MCP tool call failed: {e}"
             raise RuntimeError(msg) from e
 
-    async def _convert_mcp_content(self, mcp_content: list[Any]) -> list[str | Any]:
+    async def _convert_mcp_content(
+        self,
+        mcp_content: Sequence[ContentBlock | TextResourceContents | BlobResourceContents],
+    ) -> list[str | BinaryContent]:
         """Convert MCP content blocks to PydanticAI content types."""
         from mcp.types import (
             AudioContent,
@@ -452,12 +446,8 @@ class MCPClient:
                     try:
                         assert self._client
                         res = await self._client.read_resource_mcp(uri)
-                        if len(res.contents) == 1:
-                            nested = await self._convert_mcp_content([res.contents[0]])
-                            contents.extend(nested)
-                        else:
-                            nested = await self._convert_mcp_content(res.contents)
-                            contents.extend(nested)
+                        nested = await self._convert_mcp_content(res.contents)
+                        contents.extend(nested)
                     except Exception:  # noqa: BLE001
                         # Fallback to DocumentUrl if reading fails
                         contents.append(DocumentUrl(url=str(uri)))
@@ -473,10 +463,5 @@ class MCPClient:
 
 def _should_try_oauth_fallback(config: MCPServerConfig) -> bool:
     """Check if OAuth fallback should be attempted."""
-    from llmling_agent_config.mcp_server import StdioMCPServerConfig
-
     # No fallback for stdio or if OAuth already configured
-    if isinstance(config, StdioMCPServerConfig):
-        return False
-
-    return not config.auth.oauth
+    return not isinstance(config, StdioMCPServerConfig) and not config.auth.oauth
