@@ -8,6 +8,7 @@ from llmling_agent.messaging.messages import (
 )
 from llmling_agent.messaging.message_container import ChatMessageContainer
 from llmling_agent.messaging.event_manager import EventManager
+from llmling_agent.messaging.messageemitter import MessageEmitter
 from llmling_agent.messaging.messagenode import MessageNode
 
 __all__ = [
@@ -15,6 +16,7 @@ __all__ = [
     "ChatMessage",
     "ChatMessageContainer",
     "EventManager",
+    "MessageEmitter",
     "MessageNode",
     "TeamResponse",
     "TokenCost",
