@@ -22,9 +22,7 @@ if TYPE_CHECKING:
         AsyncFilterFn,
         QueueStrategy,
     )
-    from llmling_agent.messaging.messageemitter import MessageEmitter
-    from llmling_agent.messaging.messagenode import MessageNode
-    from llmling_agent.messaging.messages import ChatMessage
+    from llmling_agent.messaging import ChatMessage, MessageEmitter, MessageNode
     from llmling_agent_config.forward_targets import ConnectionType
 
 logger = get_logger(__name__)
@@ -193,7 +191,9 @@ class ConnectionManager:
             else:
                 pool.connection_registry.register_auto(talk)
         else:
-            logger.debug("Could not register connection %r, no pool available", name)
+            logger.debug(
+                "Could not register connection. no pool available", connection=name
+            )
         return talk
 
     async def trigger_all(self) -> dict[AgentName, list[ChatMessage[Any]]]:
