@@ -3,35 +3,38 @@
 from __future__ import annotations
 
 import asyncio
+from collections import defaultdict
 from collections.abc import Awaitable, Callable
 from dataclasses import dataclass
 from functools import wraps
 import inspect
 from typing import TYPE_CHECKING, Any, Self, overload
 
-from psygnal import Signal
-from pydantic import SecretStr
-
-from llmling_agent.log import get_logger
-from llmling_agent.messaging.events import EventData, FunctionResultEventData
-from llmling_agent.utils.inspection import execute
-from llmling_agent.utils.now import get_now
-from llmling_agent_config.events import (
+from evented.configs import (
     EmailConfig,
     FileWatchConfig,
     TimeEventConfig,
     WebhookConfig,
 )
+from evented.event_data import EventData, FunctionResultEventData
+from psygnal import Signal
+from pydantic import SecretStr
+
+from llmling_agent.log import get_logger
+from llmling_agent.utils.inspection import execute
+from llmling_agent.utils.now import get_now
 
 
 if TYPE_CHECKING:
     from collections.abc import Coroutine, Sequence
     from datetime import datetime, timedelta
+    from types import TracebackType
 
-    from llmling_agent.messaging.messageemitter import MessageEmitter
-    from llmling_agent_config.events import EventConfig
-    from llmling_agent_events.base import EventSource
-    from llmling_agent_events.timed_watcher import TimeEventSource
+    from evented.base import EventSource
+    from evented.configs import EventConfig
+    from evented.timed_watcher import TimeEventSource
+
+    from llmling_agent.messaging import MessageEmitter
 
 
 logger = get_logger(__name__)
@@ -63,7 +66,7 @@ class EventManager:
         self._sources: dict[str, EventSource] = {}
         self._callbacks: list[EventCallback] = []
         self.auto_run = auto_run
-        self._observers: dict[str, list[EventObserver]] = {}
+        self._observers = defaultdict[str, list[EventObserver]](list)
 
     async def _default_handler(self, event: EventData):
         """Default event handler that converts events to node runs."""
@@ -150,7 +153,8 @@ class EventManager:
             secret: Optional secret for request validation
         """
         name = name or f"webhook_{len(self._sources)}"
-        config = WebhookConfig(name=name, path=path, port=port, secret=secret)
+        sec = SecretStr(secret) if secret else None
+        config = WebhookConfig(name=name, path=path, port=port, secret=sec)
         return await self.add_source(config)
 
     async def add_timed_event(
@@ -235,7 +239,7 @@ class EventManager:
             ValueError: If source already exists or is invalid
         """
         logger.debug("Setting up event source", name=config.name, type=config.type)
-        from llmling_agent_events.base import EventSource
+        from evented.base import EventSource
 
         if config.name in self._sources:
             msg = f"Event source already exists: {config.name}"
@@ -243,7 +247,7 @@ class EventManager:
 
         try:
             source = EventSource.from_config(config)
-            await source.connect()
+            await source.__aenter__()
             self._sources[config.name] = source
             # Start processing events
             name = f"event_processor_{config.name}"
@@ -263,7 +267,7 @@ class EventManager:
             name: Name of source to remove
         """
         if source := self._sources.pop(name, None):
-            await source.disconnect()
+            await source.__aexit__(None, None, None)
             logger.debug("Removed event source", name=name)
 
     async def _process_events(self, source: EventSource):
@@ -310,7 +314,12 @@ class EventManager:
 
         return self
 
-    async def __aexit__(self, *exc: object):
+    async def __aexit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: TracebackType | None,
+    ) -> None:
         """Clean up when exiting context."""
         await self.cleanup()
 
@@ -430,7 +439,7 @@ class EventManager:
 
         def decorator(func: Callable[..., Any]) -> Callable[..., Any]:
             observer = EventObserver(func, interval=interval)
-            self._observers.setdefault(event_type, []).append(observer)
+            self._observers[event_type].append(observer)
 
             @wraps(func)
             async def wrapper(*args: Any, **kwargs: Any) -> Any:
@@ -464,3 +473,11 @@ class EventObserver:
             await execute(self.callback, event)
         except Exception:
             logger.exception("Error in event observer")
+
+
+if __name__ == "__main__":
+    # Example usage of the event manager
+    from llmling_agent import Agent
+
+    agent = Agent()
+    event_manager = EventManager(node=agent)
