@@ -10,48 +10,46 @@ from uuid import uuid4
 
 from psygnal import Signal
 
-from llmling_agent.messaging.messages import ChatMessage
+from llmling_agent.log import get_logger
+from llmling_agent.messaging import ChatMessage
 from llmling_agent.prompts.convert import convert_prompts
-from llmling_agent.talk.stats import AggregatedTalkStats
-from llmling_agent.tools import ToolCallInfo
+from llmling_agent.talk import AggregatedTalkStats
 from llmling_agent.utils.tasks import TaskManager
 
 
 if TYPE_CHECKING:
     from collections.abc import Coroutine
     from datetime import timedelta
-    import os
     from types import TracebackType
 
-    import PIL.Image
-    from toprompt import AnyPromptType
-
-    from llmling_agent.common_types import AnyTransformFn, AsyncFilterFn, QueueStrategy
+    from llmling_agent.common_types import (
+        AnyTransformFn,
+        AsyncFilterFn,
+        ProcessorCallback,
+        PromptCompatible,
+        QueueStrategy,
+    )
     from llmling_agent.mcp_server.client import ContextualProgressHandler
     from llmling_agent.messaging.context import NodeContext
     from llmling_agent.messaging.messagenode import MessageNode
-    from llmling_agent.models.content import Content
+    from llmling_agent.models.content import BaseContent
     from llmling_agent.talk import Talk, TeamTalk
     from llmling_agent_config.forward_targets import ConnectionType
     from llmling_agent_config.mcp_server import MCPServerConfig
-    from llmling_agent_config.providers import ProcessorCallback
+
+
+logger = get_logger(__name__)
 
 
 class MessageEmitter[TDeps, TResult](ABC):
     """Base class for all message processing nodes."""
 
-    outbox = Signal(object)  # ChatMessage
-    """Signal emitted when node produces a message."""
-
     message_received = Signal(ChatMessage)
     """Signal emitted when node receives a message."""
 
     message_sent = Signal(ChatMessage)
     """Signal emitted when node creates a message."""
 
-    tool_used = Signal(ToolCallInfo)
-    """Signal emitted when node uses a tool."""
-
     def __init__(
         self,
         name: str | None = None,
@@ -64,27 +62,25 @@ class MessageEmitter[TDeps, TResult](ABC):
         """Initialize message node."""
         super().__init__()
         from llmling_agent.mcp_server.manager import MCPManager
+        from llmling_agent.messaging import EventManager
         from llmling_agent.messaging.connection_manager import ConnectionManager
-        from llmling_agent.messaging.event_manager import EventManager
 
         self.task_manager = TaskManager()
         self._name = name or self.__class__.__name__
+        self.log = logger.bind(agent_name=self._name)
+
         self.description = description
         self.connections = ConnectionManager(self)
         self._events = EventManager(self, enable_events=True)
-        servers = mcp_servers or []
-        name = f"node_{self._name}"
         self.mcp = MCPManager(
-            name,
-            servers=servers,
+            f"node_{self._name}",
+            servers=mcp_servers or [],
             context=context,
             owner=self.name,
             progress_handler=progress_handler,
         )
         self.enable_db_logging = enable_logging
         self.conversation_id = str(uuid4())
-        # Initialize conversation record if enabled
-
         # Connect to the combined signal to capture all messages
         # TODO: need to check this
         # node.message_received.connect(self.log_message)
@@ -113,7 +109,7 @@ class MessageEmitter[TDeps, TResult](ABC):
         exc_tb: TracebackType | None,
     ):
         """Clean up base resources."""
-        await self._events.cleanup()
+        await self._events.__aexit__(exc_type, exc_val, exc_tb)
         await self.mcp.__aexit__(exc_type, exc_val, exc_tb)
         await self.task_manager.cleanup_tasks()
 
@@ -302,8 +298,8 @@ class MessageEmitter[TDeps, TResult](ABC):
 
     async def pre_run(
         self,
-        *prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | ChatMessage,
-    ) -> tuple[ChatMessage[Any], list[Content | str]]:
+        *prompt: PromptCompatible | ChatMessage,
+    ) -> tuple[ChatMessage[Any], list[BaseContent | str]]:
         """Hook to prepare a MessgeNode run call.
 
         Args:
@@ -326,12 +322,8 @@ class MessageEmitter[TDeps, TResult](ABC):
         else:
             prompts = await convert_prompts(prompt)
             final_prompt = "\n\n".join(str(p) for p in prompts)
-            # use format_prompts?
-            user_msg = ChatMessage[str](
-                content=final_prompt,
-                role="user",
-                conversation_id=str(uuid4()),
-            )
+            id_ = str(uuid4())
+            user_msg = ChatMessage(content=final_prompt, role="user", conversation_id=id_)
         self.message_received.emit(user_msg)
         self.context.current_prompt = final_prompt
         return user_msg, prompts
@@ -356,7 +348,7 @@ class MessageEmitter[TDeps, TResult](ABC):
 
     async def run(
         self,
-        *prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | ChatMessage,
+        *prompt: PromptCompatible | ChatMessage,
         wait_for_connections: bool | None = None,
         store_history: bool = True,
         **kwargs: Any,
