@@ -2,7 +2,7 @@
 
 from __future__ import annotations
 
-import dataclasses
+from collections.abc import Sequence
 from dataclasses import dataclass, field, replace
 from decimal import Decimal
 from typing import TYPE_CHECKING, Any, Literal, Self, TypeVar
@@ -11,7 +11,22 @@ from uuid import uuid4
 
 from genai_prices import calc_price
 from pydantic import BaseModel
-from pydantic_ai import ModelRequest, ModelResponse, RequestUsage
+from pydantic_ai import (
+    AudioUrl,
+    BaseToolReturnPart,
+    BinaryContent,
+    DocumentUrl,
+    FilePart,
+    ImageUrl,
+    ModelRequest,
+    ModelResponse,
+    RequestUsage,
+    TextPart,
+    ToolCallPart,
+    UserContent,
+    UserPromptPart,
+    VideoUrl,
+)
 import tokonomics
 
 from llmling_agent.common_types import MessageRole, SimpleJsonType  # noqa: TC001
@@ -20,17 +35,18 @@ from llmling_agent.utils.now import get_now
 
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
     from datetime import datetime
 
     from pydantic_ai import (
+        AgentRunResult,
         FinishReason,
+        ModelMessage,
         ModelRequestPart,
         ModelResponsePart,
         RunUsage,
     )
 
-    from llmling_agent.tools import ToolCallInfo
+    from llmling_agent.tools.tool_call_info import ToolCallInfo
 
 
 TContent = TypeVar("TContent", str, BaseModel)
@@ -105,7 +121,7 @@ class TokenCost:
     """Total cost in USD"""
 
     @classmethod
-    async def from_usage(cls, usage: RunUsage | None, model: str) -> TokenCost | None:
+    async def from_usage(cls, usage: RunUsage, model: str) -> TokenCost | None:
         """Create result from usage data.
 
         Args:
@@ -116,13 +132,7 @@ class TokenCost:
         Returns:
             TokenCost if usage data available, None otherwise
         """
-        if not (
-            usage and usage.input_tokens is not None and usage.output_tokens is not None
-        ):
-            logger.debug("Missing token counts in Usage object")
-            return None
         logger.debug("Token usage", usage=usage)
-
         # return cls(token_usage=token_usage, total_cost=Decimal(total_cost))
         if model in {"None", "test"}:
             price = Decimal(0)
@@ -178,9 +188,6 @@ class ChatMessage[TContent]:
     response_time: float | None = None
     """Time it took the LLM to respond."""
 
-    tool_calls: list[ToolCallInfo] = field(default_factory=list)
-    """List of tool calls made during message generation."""
-
     associated_messages: list[ChatMessage[Any]] = field(default_factory=list)
     """List of messages which were generated during the the creation of this messsage."""
 
@@ -193,8 +200,8 @@ class ChatMessage[TContent]:
     provider_details: dict[str, Any] = field(default_factory=dict)
     """Provider specific metadata / extra information."""
 
-    parts: Sequence[ModelResponsePart | ModelRequestPart] = field(default_factory=list)
-    """The parts of the model message."""
+    messages: list[ModelMessage] = field(default_factory=list)
+    """List of messages which were generated during the the creation of this messsage."""
 
     usage: RequestUsage = field(default_factory=RequestUsage)
     """Usage information for the request.
@@ -219,6 +226,22 @@ class ChatMessage[TContent]:
 
     Normalized to OpenTelemetry values."""
 
+    @property
+    def last_message(self) -> ModelMessage:
+        """Return the last message from the message history."""
+        # The response may not be the very last item if it contained an output tool call.
+        # See `CallToolsNode._handle_final_result`.
+        for message in reversed(self.messages):
+            if isinstance(message, ModelRequest | ModelResponse):
+                return message
+        msg = "No last message found in the message history"
+        raise ValueError(msg)  # pragma: no cover
+
+    @property
+    def parts(self) -> Sequence[ModelRequestPart] | Sequence[ModelResponsePart]:
+        """The parts of the last model message."""
+        return self.last_message.parts
+
     @property
     def kind(self) -> Literal["request", "response"]:
         """Role of the message."""
@@ -228,28 +251,49 @@ class ChatMessage[TContent]:
             case "user":
                 return "request"
 
-    def to_pydantic_ai(self) -> ModelRequest | ModelResponse:
+    def to_pydantic_ai(self) -> Sequence[ModelMessage]:
         """Convert this message to a Pydantic model."""
+        if self.messages:
+            return self.messages
         match self.kind:
             case "request":
-                return ModelRequest(parts=self.parts, instructions=None)  # type: ignore
+                return [ModelRequest(parts=self.parts, instructions=None)]  # type: ignore
             case "response":
-                return ModelResponse(
-                    parts=self.parts,  # type: ignore
-                    usage=self.usage,
-                    model_name=self.model_name,
-                    timestamp=self.timestamp,
-                    provider_name=self.provider_name,
-                    provider_details=self.provider_details,
-                    finish_reason=self.finish_reason,
-                    provider_response_id=self.provider_response_id,
-                )
+                return [
+                    ModelResponse(
+                        parts=self.parts,  # type: ignore
+                        usage=self.usage,
+                        model_name=self.model_name,
+                        timestamp=self.timestamp,
+                        provider_name=self.provider_name,
+                        provider_details=self.provider_details,
+                        finish_reason=self.finish_reason,
+                        provider_response_id=self.provider_response_id,
+                    )
+                ]
+
+    @classmethod
+    def user_prompt[TPromptContent: str | Sequence[UserContent] = str](
+        cls,
+        message: TPromptContent,
+        conversation_id: str | None = None,
+        instructions: str | None = None,
+    ) -> ChatMessage[TPromptContent]:
+        """Create a user prompt message."""
+        part = UserPromptPart(content=message)
+        request = ModelRequest(parts=[part], instructions=instructions)
+        return ChatMessage(
+            messages=[request],
+            role="user",
+            content=message,
+            conversation_id=conversation_id or str(uuid4()),
+        )
 
     @classmethod
     def from_pydantic_ai[TContentType](
         cls,
         content: TContentType,
-        message: ModelRequest | ModelResponse,
+        message: ModelMessage,
         conversation_id: str | None = None,
         name: str | None = None,
         message_id: str | None = None,
@@ -257,9 +301,9 @@ class ChatMessage[TContent]:
     ) -> ChatMessage[TContentType]:
         """Convert a Pydantic model to a ChatMessage."""
         match message:
-            case ModelRequest(parts=parts, instructions=_instructions):
+            case ModelRequest(instructions=_instructions):
                 return ChatMessage(
-                    parts=parts,
+                    messages=[message],
                     content=content,
                     role="user" if message.kind == "request" else "assistant",
                     message_id=message_id or str(uuid.uuid4()),
@@ -268,7 +312,6 @@ class ChatMessage[TContent]:
                     name=name,
                 )
             case ModelResponse(
-                parts=parts,
                 usage=usage,
                 model_name=model_name,
                 timestamp=timestamp,
@@ -280,7 +323,7 @@ class ChatMessage[TContent]:
                 return ChatMessage(
                     role="user" if message.kind == "request" else "assistant",
                     content=content,
-                    parts=parts,
+                    messages=[message],
                     usage=usage,
                     message_id=message_id or str(uuid.uuid4()),
                     conversation_id=conversation_id,
@@ -297,6 +340,52 @@ class ChatMessage[TContent]:
                 msg = f"Unknown message kind: {message.kind}"
                 raise ValueError(msg)
 
+    @classmethod
+    async def from_run_result[OutputDataT](
+        cls,
+        result: AgentRunResult[OutputDataT],
+        *,
+        agent_name: str | None = None,
+        message_id: str | None = None,
+        conversation_id: str | None = None,
+        response_time: float,
+    ) -> ChatMessage[OutputDataT]:
+        """Create a ChatMessage from a PydanticAI run result.
+
+        Args:
+            result: The PydanticAI run result
+            agent_name: Name of the agent that generated this response
+            message_id: Unique message identifier
+            conversation_id: Conversation identifier
+            response_time: Total time taken for the response
+
+        Returns:
+            A ChatMessage with all fields populated from the result
+        """
+        # Calculate costs
+        run_usage = result.usage()
+        usage = result.response.usage
+        cost_info = await TokenCost.from_usage(
+            model=result.response.model_name or "", usage=run_usage
+        )
+
+        return ChatMessage[OutputDataT](
+            content=result.output,
+            role="assistant",
+            name=agent_name,
+            model_name=result.response.model_name,
+            finish_reason=result.response.finish_reason,
+            messages=result.new_messages(),
+            provider_response_id=result.response.provider_response_id,
+            usage=usage,
+            provider_name=result.response.provider_name,
+            message_id=message_id or str(uuid4()),
+            conversation_id=conversation_id,
+            cost_info=cost_info,
+            response_time=response_time,
+            provider_details={},
+        )
+
     def forwarded(self, previous_message: ChatMessage[Any]) -> Self:
         """Create new message showing it was forwarded from another message.
 
@@ -309,15 +398,132 @@ class ChatMessage[TContent]:
         from_ = [*previous_message.forwarded_from, previous_message.name or "unknown"]
         return replace(self, forwarded_from=from_)
 
-    def to_text_message(self) -> ChatMessage[str]:
-        """Convert this message to a text-only version."""
-        return dataclasses.replace(self, content=str(self.content))  # type: ignore
+    @property
+    def response(self) -> ModelResponse:
+        """Return the last response from the message history."""
+        # The response may not be the very last item if it contained an output tool call.
+        #  See `CallToolsNode._handle_final_result`.
+        for message in reversed(self.messages):
+            if isinstance(message, ModelResponse):
+                return message
+        msg = "No response found in the message history"
+        raise ValueError(msg)
+
+    def to_request(self) -> Self:
+        """Convert this message to a request message.
+
+        If the message is already a request (user role), this is a no-op.
+        If it's a response (assistant role), converts response parts to user content.
+
+        Returns:
+            New ChatMessage with role='user' and converted parts
+        """
+        if self.role == "user":
+            return self  # Already a request, return as-is
+
+        user_content: list[UserContent] = []  # Convert response parts to user content
+        for part in self.parts:
+            match part:
+                case TextPart(content=text_content):
+                    # Text parts become user content strings
+                    user_content.append(text_content)
+                case FilePart(content=binary_content):
+                    # File parts (images, etc.) become user content directly
+                    user_content.append(binary_content)
+                case BaseToolReturnPart(
+                    content=(
+                        ImageUrl()
+                        | AudioUrl()
+                        | DocumentUrl()
+                        | VideoUrl()
+                        | BinaryContent()
+                        | str(),
+                    ) as content
+                ):
+                    user_content.extend(content)
+                case BaseToolReturnPart(
+                    content=(
+                        str()
+                        | ImageUrl()
+                        | AudioUrl()
+                        | DocumentUrl()
+                        | VideoUrl()
+                        | BinaryContent()
+                    ) as content
+                ):
+                    user_content.append(content)
+                case BaseToolReturnPart():
+                    # Tool return parts become user content strings
+                    user_content.append(part.model_response_str())
+                case ToolCallPart():
+                    # Tool return parts become user content strings
+                    user_content.append(part.args_as_json_str())
+                case _:
+                    pass
+
+        # Create new UserPromptPart with converted content
+        if user_content:
+            converted_parts = [UserPromptPart(content=user_content)]
+        else:
+            converted_parts = [UserPromptPart(content=str(self.content))]
+
+        return replace(
+            self,
+            role="user",
+            messages=[ModelRequest(parts=converted_parts)],
+            cost_info=None,
+            # TODO: what about message_id?
+        )
 
     @property
     def data(self) -> TContent:
         """Get content as typed data. Provides compat to AgentRunResult."""
         return self.content
 
+    def get_tool_calls(
+        self,
+        tools: dict[str, Any] | None = None,
+        agent_name: str | None = None,
+    ) -> list[ToolCallInfo]:
+        """Extract tool call information from all messages lazily.
+
+        Args:
+            tools: Original Tool set to enrich ToolCallInfos with additional info
+            agent_name: Name of the caller
+        """
+        from uuid import uuid4
+
+        from pydantic_ai import ToolReturnPart
+
+        from llmling_agent.tools import ToolCallInfo
+
+        tools = tools or {}
+        parts = [part for message in self.messages for part in message.parts]
+        call_parts = {
+            part.tool_call_id: part
+            for part in parts
+            if isinstance(part, ToolCallPart) and part.tool_call_id
+        }
+
+        tool_calls = []
+        for part in parts:
+            if isinstance(part, ToolReturnPart) and part.tool_call_id in call_parts:
+                call_part = call_parts[part.tool_call_id]
+                tool_info = ToolCallInfo(
+                    tool_name=call_part.tool_name,
+                    args=call_part.args_as_dict(),
+                    agent_name=agent_name or "UNSET",
+                    result=part.content,
+                    tool_call_id=call_part.tool_call_id or str(uuid4()),
+                    timestamp=part.timestamp,
+                    agent_tool_name=(
+                        t.agent_name if (t := tools.get(part.tool_name)) else None
+                    ),
+                )
+                tool_calls.append(tool_info)
+
+        return tool_calls
+
     def format(
         self,
         style: FormatStyle = "simple",
@@ -363,7 +569,7 @@ class ChatMessage[TContent]:
             "show_metadata": show_metadata,
             "show_costs": show_costs,
         }
-        print(vars_)
+
         if variables:
             vars_.update(variables)
 
