@@ -9,32 +9,22 @@ from uuid import UUID
 
 from llmling import (
     BasePrompt,
-    Config,
-    ConfigStore,
-    GlobalSettings,
-    LLMCapabilitiesConfig,
     PromptMessage,
     StaticPrompt,
 )
-from llmling.utils.importing import import_callable, import_class
 from pydantic import Field, model_validator
+from pydantic_ai import UsageLimits  # noqa: TC002
 from schemez import InlineSchemaDef
 from toprompt import render_prompt
-from upath import UPath
 
 from llmling_agent import log
 from llmling_agent.common_types import EndStrategy  # noqa: TC001
 from llmling_agent.resource_providers.static import StaticResourceProvider
-from llmling_agent_config.environment import (
-    AgentEnvironment,  # noqa: TC001
-    FileEnvironment,
-    InlineEnvironment,
-)
+from llmling_agent.utils.importing import import_class
 from llmling_agent_config.knowledge import Knowledge  # noqa: TC001
 from llmling_agent_config.models import AnyModelConfig  # noqa: TC001
 from llmling_agent_config.nodes import NodeConfig
 from llmling_agent_config.output_types import StructuredResponseConfig  # noqa: TC001
-from llmling_agent_config.providers import ProviderConfig  # noqa: TC001
 from llmling_agent_config.session import MemoryConfig, SessionQuery
 from llmling_agent_config.system_prompts import PromptConfig  # noqa: TC001
 from llmling_agent_config.tools import BaseToolConfig, ToolConfig  # noqa: TC001
@@ -43,13 +33,11 @@ from llmling_agent_config.workers import WorkerConfig  # noqa: TC001
 
 
 if TYPE_CHECKING:
-    from llmling_agent.resource_providers.base import ResourceProvider
+    from llmling_agent.resource_providers import ResourceProvider
     from llmling_agent.tools.base import Tool
-    from llmling_agent_providers.base import AgentProvider
 
 
 ToolConfirmationMode = Literal["always", "never", "per_tool"]
-ProviderName = Literal["pydantic_ai", "human"]
 
 logger = log.get_logger(__name__)
 
@@ -67,9 +55,6 @@ class AgentConfig(NodeConfig):
     The configuration can be loaded from YAML or created programmatically.
     """
 
-    provider: ProviderConfig | ProviderName = "pydantic_ai"
-    """Provider configuration or shorthand type"""
-
     inherits: str | None = None
     """Name of agent config to inherit from"""
 
@@ -83,9 +68,6 @@ class AgentConfig(NodeConfig):
     toolsets: list[ToolsetConfig] = Field(default_factory=list)
     """Toolset configurations for extensible tool collections."""
 
-    environment: str | AgentEnvironment | None = None
-    """Environments configuration (path or object)"""
-
     session: str | SessionQuery | MemoryConfig | None = None
     """Session configuration for conversation recovery."""
 
@@ -138,6 +120,9 @@ class AgentConfig(NodeConfig):
     debug: bool = False
     """Enable debug output for this agent."""
 
+    usage_limits: UsageLimits | None = None
+    """Usage limits for this agent."""
+
     def is_structured(self) -> bool:
         """Check if this config defines a structured agent."""
         return self.output_type is not None
@@ -216,7 +201,7 @@ class AgentConfig(NodeConfig):
                     case BaseToolConfig():
                         static_tools.append(tool_config.get_tool())
             except Exception:
-                logger.exception("Failed to load tool %r", tool_config)
+                logger.exception("Failed to load tool", config=tool_config)
                 continue
 
         return StaticResourceProvider(name="builtin", tools=static_tools)
@@ -303,38 +288,6 @@ class AgentConfig(NodeConfig):
                     prompts.append(prompt)
         return prompts
 
-    def get_provider(self) -> AgentProvider:
-        """Get resolved provider instance.
-
-        Creates provider instance based on configuration:
-        - Full provider config: Use as-is
-        - Shorthand type: Create default provider config
-        """
-        # If string shorthand is used, convert to default provider config
-        from llmling_agent_config.providers import (
-            CallbackProviderConfig,
-            HumanProviderConfig,
-            PydanticAIProviderConfig,
-        )
-
-        provider_config = self.provider
-        if isinstance(provider_config, str):
-            match provider_config:
-                case "pydantic_ai":
-                    provider_config = PydanticAIProviderConfig(model=self.model)
-                case "human":
-                    provider_config = HumanProviderConfig()
-                case _:
-                    try:
-                        fn = import_callable(provider_config)
-                        provider_config = CallbackProviderConfig(callback=fn)
-                    except Exception:  # noqa: BLE001
-                        msg = f"Invalid provider type: {provider_config}"
-                        raise ValueError(msg)  # noqa: B904
-
-        # Create provider instance from config
-        return provider_config.get_provider()
-
     def render_system_prompts(self, context: dict[str, Any] | None = None) -> list[str]:
         """Render system prompts with context."""
         from llmling_agent_config.system_prompts import (
@@ -375,55 +328,6 @@ class AgentConfig(NodeConfig):
 
         return rendered_prompts
 
-    def get_config(self) -> Config:
-        """Get configuration for this agent."""
-        match self.environment:
-            case None:
-                # Create minimal config
-                caps = LLMCapabilitiesConfig()
-                global_settings = GlobalSettings(llm_capabilities=caps)
-                return Config(global_settings=global_settings)
-            case str() as path:
-                # Backward compatibility: treat as file path
-                resolved = self._resolve_environment_path(path, self.config_file_path)
-                return Config.from_file(resolved)
-            case FileEnvironment(uri=uri) as env:
-                # Handle FileEnvironment instance
-                resolved = env.get_file_path()
-                return Config.from_file(resolved)
-            case {"type": "file", "uri": uri}:
-                # Handle raw dict matching file environment structure
-                return Config.from_file(uri)
-            case {"type": "inline", "config": config}:
-                return config
-            case InlineEnvironment() as config:
-                return config
-            case _:
-                msg = f"Invalid environment configuration: {self.environment}"
-                raise ValueError(msg)
-
-    def get_environment_path(self) -> str | None:
-        """Get environment file path if available."""
-        match self.environment:
-            case str() as path:
-                return self._resolve_environment_path(path, self.config_file_path)
-            case {"type": "file", "uri": uri} | FileEnvironment(uri=uri):
-                return uri
-            case _:
-                return None
-
-    @staticmethod
-    def _resolve_environment_path(env: str, config_file_path: str | None = None) -> str:
-        """Resolve environment path from config store or relative path."""
-        try:
-            config_store = ConfigStore()
-            return config_store.get_config(env)
-        except KeyError:
-            if config_file_path:
-                base_dir = UPath(config_file_path).parent
-                return str(base_dir / env)
-            return env
-
 
 if __name__ == "__main__":
     model = "openai:gpt-5-nano"
