@@ -4,15 +4,23 @@ from __future__ import annotations
 
 import base64
 import io
-from typing import TYPE_CHECKING, Annotated, Any, Literal, Self
+from typing import TYPE_CHECKING, Annotated, Literal, Self
 
 from pydantic import ConfigDict, Field
+from pydantic_ai import (
+    AudioUrl,
+    BinaryContent,
+    BinaryImage,
+    DocumentUrl,
+    ImageUrl,
+)
 from schemez import Schema
 from upathtools import read_path
 
 
 if TYPE_CHECKING:
     import PIL.Image
+    from pydantic_ai import UserContent
     from upath.types import JoinablePathLike
 
 
@@ -30,9 +38,9 @@ class BaseContent(Schema):
 
     model_config = ConfigDict(frozen=True)
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format."""
-        raise NotImplementedError
+    def to_pydantic_ai(self) -> UserContent:
+        msg = "Subclasses must implement this method"
+        raise NotImplementedError(msg)
 
 
 class BaseImageContent(BaseContent):
@@ -88,10 +96,8 @@ class ImageURLContent(BaseImageContent):
     url: str
     """URL to the image."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for vision models."""
-        content = {"url": self.url, "detail": self.detail or "auto"}
-        return {"type": "image_url", "image_url": content}
+    def to_pydantic_ai(self) -> ImageUrl:
+        return ImageUrl(url=self.url)
 
 
 class ImageBase64Content(BaseImageContent):
@@ -106,11 +112,9 @@ class ImageBase64Content(BaseImageContent):
     mime_type: str = "image/jpeg"
     """MIME type of the image."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for vision models."""
-        data_url = f"data:{self.mime_type};base64,{self.data}"
-        content = {"url": data_url, "detail": self.detail or "auto"}
-        return {"type": "image_url", "image_url": content}
+    def to_pydantic_ai(self) -> BinaryImage:
+        binary_data = base64.b64decode(self.data)
+        return BinaryImage(data=binary_data, media_type=self.mime_type or "image/jpeg")
 
     @classmethod
     def from_bytes(
@@ -144,10 +148,6 @@ class BasePDFContent(BaseContent):
     detail: DetailLevel | None = None
     """Detail level for document processing by models."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for PDF handling."""
-        raise NotImplementedError
-
     @classmethod
     async def from_path(
         cls,
@@ -188,10 +188,8 @@ class PDFURLContent(BasePDFContent):
     url: str
     """URL to the PDF document."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for PDF handling."""
-        content = {"url": self.url, "detail": self.detail or "auto"}
-        return {"type": "file", "file": content}
+    def to_pydantic_ai(self) -> DocumentUrl:
+        return DocumentUrl(url=self.url)
 
 
 class PDFBase64Content(BasePDFContent):
@@ -203,12 +201,6 @@ class PDFBase64Content(BasePDFContent):
     data: str
     """Base64-encoded PDF data."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for PDF handling."""
-        data_url = f"data:application/pdf;base64,{self.data}"
-        content = {"url": data_url, "detail": self.detail or "auto"}
-        return {"type": "file", "file": content}
-
     @classmethod
     def from_bytes(
         cls,
@@ -221,6 +213,10 @@ class PDFBase64Content(BasePDFContent):
         content = base64.b64encode(data).decode()
         return cls(data=content, detail=detail, description=description)
 
+    def to_pydantic_ai(self) -> BinaryContent:
+        binary_data = base64.b64decode(self.data)
+        return BinaryContent(binary_data, media_type="application/pdf")
+
 
 class AudioContent(BaseContent):
     """Base for audio content."""
@@ -241,10 +237,8 @@ class AudioURLContent(AudioContent):
     url: str
     """URL to the audio."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for audio models."""
-        content = {"url": self.url, "format": self.format or "auto"}
-        return {"type": "audio", "audio": content}
+    def to_pydantic_ai(self) -> AudioUrl:
+        return AudioUrl(url=self.url)
 
 
 class AudioBase64Content(AudioContent):
@@ -259,11 +253,9 @@ class AudioBase64Content(AudioContent):
     format: str | None = None  # mp3, wav, etc
     """Audio format."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for audio models."""
-        data_url = f"data:audio/{self.format or 'mp3'};base64,{self.data}"
-        content = {"url": data_url, "format": self.format or "auto"}
-        return {"type": "audio", "audio": content}
+    def to_pydantic_ai(self) -> BinaryContent:
+        binary_data = base64.b64decode(self.data)
+        return BinaryContent(data=binary_data, media_type=f"audio/{self.format or 'mp3'}")
 
     @classmethod
     def from_bytes(cls, data: bytes, audio_format: str = "mp3") -> Self:
@@ -312,11 +304,6 @@ class VideoURLContent(VideoContent):
     url: str
     """URL to the video."""
 
-    def to_openai_format(self) -> dict[str, Any]:
-        """Convert to OpenAI API format for video models."""
-        content = {"url": self.url, "format": self.format or "auto"}
-        return {"type": "video", "video": content}
-
 
 Content = Annotated[
     ImageURLContent
