@@ -12,6 +12,10 @@ from schemez.schema import Schema
 from llmling_agent import log
 from llmling_agent.models.agents import AgentConfig  # noqa: TC001
 from llmling_agent.resource_registry import ResourceRegistry
+from llmling_agent_config.commands import (  # noqa: TC001
+    CommandConfig,
+    StaticCommandConfig,
+)
 from llmling_agent_config.converters import ConversionConfig
 from llmling_agent_config.mcp_server import (
     BaseMCPServerConfig,
@@ -20,7 +24,6 @@ from llmling_agent_config.mcp_server import (
 from llmling_agent_config.observability import ObservabilityConfig
 from llmling_agent_config.output_types import StructuredResponseConfig  # noqa: TC001
 from llmling_agent_config.pool_server import MCPPoolServerConfig
-from llmling_agent_config.providers import BaseProviderConfig
 from llmling_agent_config.resources import (  # noqa: TC001
     ResourceConfig,
     SourceResourceConfig,
@@ -108,6 +111,17 @@ class AgentsManifest(Schema):
 
     prompts: PromptLibraryConfig = Field(default_factory=PromptLibraryConfig)
 
+    commands: dict[str, CommandConfig | str] = Field(default_factory=dict)
+    """Global command shortcuts for prompt injection.
+
+    Supports both shorthand string syntax and full command configurations:
+        commands:
+          df: "check disk space"  # shorthand -> StaticCommandConfig
+          analyze:  # full config
+            type: file
+            path: "./prompts/analysis.md"
+    """
+
     model_config = ConfigDict(use_attribute_docstrings=True, extra="forbid")
 
     @model_validator(mode="before")
@@ -318,6 +332,25 @@ class AgentsManifest(Schema):
             for cfg in self.mcp_servers
         ]
 
+    def get_command_configs(self) -> dict[str, CommandConfig]:
+        """Get processed command configurations.
+
+        Converts string entries to StaticCommandConfig instances.
+
+        Returns:
+            Dict mapping command names to CommandConfig instances
+        """
+        result: dict[str, CommandConfig] = {}
+        for name, config in self.commands.items():
+            if isinstance(config, str):
+                result[name] = StaticCommandConfig(name=name, content=config)
+            else:
+                # Set name if not provided
+                if config.name is None:
+                    config.name = name
+                result[name] = config
+        return result
+
     @cached_property
     def prompt_manager(self) -> PromptManager:
         """Get prompt manager for this manifest."""
@@ -341,20 +374,16 @@ class AgentsManifest(Schema):
         self, name: str, deps: TAgentDeps | None = None
     ) -> Agent[TAgentDeps, Any]:
         # TODO: Make this method async to support async function prompts
-        from llmling import RuntimeConfig
 
         from llmling_agent import Agent, AgentContext
 
         config = self.agents[name]
-        cfg = config.get_config()
-        runtime = RuntimeConfig.from_config(cfg)  # Create runtime without async context
         # Create context with config path and capabilities
         context = AgentContext[TAgentDeps](
             node_name=name,
             data=deps,
             definition=self,
             config=config,
-            runtime=runtime,
             # pool=self,
             # confirmation_callback=confirmation_callback,
         )
@@ -402,9 +431,10 @@ class AgentsManifest(Schema):
                     sys_prompts.append(content)
         # Create agent with runtime and context
         return Agent(
-            runtime=runtime,
             context=context,
-            provider=config.get_provider(),
+            model=config.model
+            if isinstance(config.model, str) or config.model is None
+            else config.model.get_model(),
             system_prompt=sys_prompts,
             name=name,
             description=config.description,
@@ -417,16 +447,6 @@ class AgentsManifest(Schema):
             # name=config.name or name,
         )
 
-    def get_used_providers(self) -> set[str]:
-        """Get all providers configured in this manifest."""
-        providers = set[str]()
-
-        for agent_config in self.agents.values():
-            match agent_config.provider:
-                case ("pydantic_ai" as typ) | BaseProviderConfig(type=typ):
-                    providers.add(typ)
-        return providers
-
     @classmethod
     def from_file(cls, path: JoinablePathLike) -> Self:
         """Load agent configuration from YAML file.
@@ -474,7 +494,7 @@ class AgentsManifest(Schema):
         agent_config = self.agents[agent_name]
         if not agent_config.output_type:
             return None
-        logger.debug("Building response model for %r", agent_config.output_type)
+        logger.debug("Building response model", type=agent_config.output_type)
         if isinstance(agent_config.output_type, str):
             response_def = self.responses[agent_config.output_type]
             return response_def.response_schema.get_schema()  # type: ignore
