@@ -2,44 +2,25 @@
 
 from __future__ import annotations
 
-from importlib.util import find_spec
 import os
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 
 from toprompt import to_prompt
-from upathtools import read_path
+import upath
+from upathtools import read_path, to_upath
 
-from llmling_agent.models.content import (
-    BaseContent,
-    BaseImageContent,
-    BasePDFContent,
-    ImageBase64Content,
-)
+from llmling_agent.models.content import BaseContent, BaseImageContent, BasePDFContent
 
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
-    import PIL.Image
-    from toprompt import AnyPromptType
-
-    from llmling_agent.models.content import (
-        Content,
-    )
-
-
-def is_pil_image(obj: Any) -> bool:
-    """Check if object is a PIL.Image.Image instance without direct import."""
-    if not find_spec("PIL"):
-        return False
-    import PIL.Image
-
-    return isinstance(obj, PIL.Image.Image)
+    from llmling_agent.common_types import PromptCompatible
 
 
 async def convert_prompts(
-    prompts: Sequence[AnyPromptType | PIL.Image.Image | os.PathLike[str] | Content],
-) -> list[str | Content]:
+    prompts: Sequence[PromptCompatible | BaseContent],
+) -> list[str | BaseContent]:
     """Convert prompts to our internal format.
 
     Handles:
@@ -48,24 +29,18 @@ async def convert_prompts(
     - Regular prompts -> str via to_prompt
     - Content objects -> pass through
     """
-    result: list[str | Content] = []
+    result: list[str | BaseContent] = []
     for p in prompts:
         match p:
-            case _ if is_pil_image(p):
-                # Only convert PIL images if PIL is available
-                result.append(ImageBase64Content.from_pil_image(p))  # type: ignore
-
-            case os.PathLike():
+            case os.PathLike() | upath.UPath():
                 from mimetypes import guess_type
 
-                from upathtools import to_upath
-
                 path_obj = to_upath(p)
                 mime_type, _ = guess_type(str(path_obj))
 
                 match mime_type:
                     case "application/pdf":
-                        content: Content = await BasePDFContent.from_path(path_obj)
+                        content: BaseContent = await BasePDFContent.from_path(path_obj)
                         result.append(content)
                     case str() if mime_type.startswith("image/"):
                         content = await BaseImageContent.from_path(path_obj)
@@ -82,7 +57,7 @@ async def convert_prompts(
     return result
 
 
-async def format_prompts(prompts: Sequence[str | Content]) -> str:
+async def format_prompts(prompts: Sequence[str | BaseContent]) -> str:
     """Format prompts for human readability using to_prompt."""
     from toprompt import to_prompt
 
