@@ -11,10 +11,10 @@ from llmling_agent.log import get_logger
 from llmling_agent.prompts.builtin_provider import BuiltinPromptProvider
 from llmling_agent.utils.tasks import TaskManager
 from llmling_agent_config.prompt_hubs import (
+    BraintrustConfig,
+    FabricConfig,
     LangfuseConfig,
-    OpenLITConfig,
     PromptLayerConfig,
-    TraceloopConfig,
 )
 
 
@@ -91,20 +91,21 @@ class PromptManager:
                     from llmling_agent_prompts.langfuse_hub import LangfusePromptHub
 
                     self.providers["langfuse"] = LangfusePromptHub(provider_config)
-                case OpenLITConfig():
-                    from llmling_agent_prompts.openlit_provider import OpenLITProvider
 
-                    self.providers["openlit"] = OpenLITProvider(provider_config)
+                case FabricConfig():
+                    from llmling_agent_prompts.fabric import FabricPromptHub
+
+                    self.providers["fabric"] = FabricPromptHub(provider_config)
+
+                case BraintrustConfig():
+                    from llmling_agent_prompts.braintrust_hub import BraintrustPromptHub
+
+                    self.providers["braintrust"] = BraintrustPromptHub(provider_config)
+
                 case PromptLayerConfig():
                     from llmling_agent_prompts.promptlayer import PromptLayerProvider
 
                     self.providers["promptlayer"] = PromptLayerProvider(provider_config)
-                case TraceloopConfig():
-                    from llmling_agent_prompts.traceloop_provider import (
-                        TraceloopPromptHub,
-                    )
-
-                    self.providers["traceloop"] = TraceloopPromptHub(provider_config)
 
     async def get_from(
         self,
@@ -160,7 +161,6 @@ class PromptManager:
         Examples:
             await prompts.get("error_handler")  # Builtin prompt
             await prompts.get("langfuse:code_review@v2?style=detailed")
-            await prompts.get("openlit:explain?context=web,detail=high")
         """
         provider_name, id_, version, vars_ = parse_prompt_reference(reference)
         prov = provider_name if provider_name != "builtin" else None
