@@ -11,7 +11,7 @@ from typing import TYPE_CHECKING, Any, Self, overload
 from psygnal import Signal
 
 from llmling_agent.log import get_logger
-from llmling_agent.messaging.messages import ChatMessage
+from llmling_agent.messaging import ChatMessage
 from llmling_agent.talk.stats import AggregatedTalkStats, TalkStats
 from llmling_agent.utils.inspection import execute
 from llmling_agent.utils.now import get_now
@@ -20,18 +20,20 @@ from llmling_agent.utils.now import get_now
 if TYPE_CHECKING:
     from collections.abc import Awaitable, Iterator
     from datetime import datetime, timedelta
-    import os
 
-    import PIL.Image
-    from toprompt import AnyPromptType
+    from evented.event_data import EventData
 
-    from llmling_agent.common_types import AnyFilterFn, AnyTransformFn, QueueStrategy
-    from llmling_agent.messaging.events import ConnectionEventData, EventData
-    from llmling_agent.messaging.messageemitter import MessageEmitter
-    from llmling_agent.messaging.messagenode import MessageNode
+    from llmling_agent.common_types import (
+        AnyFilterFn,
+        AnyTransformFn,
+        ProcessorCallback,
+        PromptCompatible,
+        QueueStrategy,
+    )
+    from llmling_agent.messaging import MessageEmitter, MessageNode
+    from llmling_agent.messaging.events import ConnectionEventData
     from llmling_agent_config.events import ConnectionEventType
     from llmling_agent_config.forward_targets import ConnectionType
-    from llmling_agent_config.providers import ProcessorCallback
 
 logger = get_logger(__name__)
 
@@ -307,7 +309,7 @@ class Talk[TTransmittedData]:
         self,
         message: ChatMessage[Any],
         target: MessageNode,
-        prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None = None,
+        prompt: PromptCompatible | None = None,
     ) -> ChatMessage[Any] | None:
         """Process message for a single target."""
         from llmling_agent.agent import Agent
@@ -315,9 +317,7 @@ class Talk[TTransmittedData]:
 
         match self.connection_type:
             case "run":
-                prompts: list[AnyPromptType | PIL.Image.Image | os.PathLike[str]] = [
-                    message
-                ]
+                prompts: list[PromptCompatible] = [message]
                 if prompt:
                     prompts.append(prompt)
                 return await target.run(*prompts)
@@ -358,18 +358,18 @@ class Talk[TTransmittedData]:
                 if self.delay is not None or self.priority != 0:
 
                     async def delayed_emit():
-                        target.outbox.emit(message, prompt)
+                        await target.connections.route_message(message)
 
                     coro = delayed_emit()
                     target.task_manager.run_background(
                         coro, priority=self.priority, delay=self.delay
                     )
                 else:
-                    target.outbox.emit(message, prompt)
+                    await target.connections.route_message(message)
                 return None
 
     async def trigger(
-        self, prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None = None
+        self, prompt: PromptCompatible | None = None
     ) -> list[ChatMessage[TTransmittedData]]:
         """Process queued messages."""
         if not self._pending_messages:
@@ -562,9 +562,7 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
         for talk in self:
             await talk._handle_message(message, prompt)
 
-    async def trigger(
-        self, prompt: AnyPromptType | PIL.Image.Image | os.PathLike[str] | None = None
-    ) -> list[ChatMessage]:
+    async def trigger(self, prompt: PromptCompatible | None = None) -> list[ChatMessage]:
         messages = []
         for talk in self:
             messages.extend(await talk.trigger(prompt))
