@@ -5,5 +5,13 @@ from __future__ import annotations
 from llmling_agent.tools.base import ToolContext, Tool
 from llmling_agent.tools.manager import ToolManager, ToolError
 from llmling_agent.tools.tool_call_info import ToolCallInfo
+from llmling_agent.tools.skills import SkillsRegistry
 
-__all__ = ["Tool", "ToolCallInfo", "ToolContext", "ToolError", "ToolManager"]
+__all__ = [
+    "SkillsRegistry",
+    "Tool",
+    "ToolCallInfo",
+    "ToolContext",
+    "ToolError",
+    "ToolManager",
+]
