@@ -8,8 +8,6 @@ from contextlib import contextmanager
 from dataclasses import dataclass, field, fields
 from typing import TYPE_CHECKING, Any, Literal
 
-from llmling import BaseRegistry, LLMCallableTool, ToolError
-from llmling.utils.importing import import_class
 from psygnal import Signal
 
 from llmling_agent.log import get_logger
@@ -17,6 +15,8 @@ from llmling_agent.resource_providers.callable_provider import (
     CallableResourceProvider,
 )
 from llmling_agent.tools.base import Tool
+from llmling_agent.utils.baseregistry import BaseRegistry, LLMLingError
+from llmling_agent.utils.importing import import_class
 from llmling_agent.utils.now import get_now
 
 
@@ -26,10 +26,9 @@ if TYPE_CHECKING:
 
     from llmling_agent import Agent, MessageNode
     from llmling_agent.common_types import AnyCallable, ToolSource, ToolType
-    from llmling_agent.resource_providers.base import ResourceProvider
-    from llmling_agent.resource_providers.callable_provider import (
-        ResourceCallable,
-    )
+    from llmling_agent.mcp_server.manager import Prompt
+    from llmling_agent.resource_providers import ResourceProvider
+    from llmling_agent.resource_providers.callable_provider import ResourceCallable
 
 
 logger = get_logger(__name__)
@@ -40,6 +39,10 @@ ProviderName = str
 OwnerType = Literal["pool", "team", "node"]
 
 
+class ToolError(LLMLingError):
+    """Base exception for tool-related errors."""
+
+
 class ToolManager(BaseRegistry[str, Tool]):
     """Manages tool registration, enabling/disabling and access.
 
@@ -98,7 +101,7 @@ class ToolManager(BaseRegistry[str, Tool]):
                      returning tools. Callables are automatically wrapped.
             owner: Optional owner for the provider
         """
-        from llmling_agent.resource_providers.base import ResourceProvider
+        from llmling_agent.resource_providers import ResourceProvider
 
         if not isinstance(provider, ResourceProvider):
             # Wrap old-style callable in ResourceProvider
@@ -116,7 +119,7 @@ class ToolManager(BaseRegistry[str, Tool]):
         self, provider: ResourceProvider | ResourceCallable | ProviderName
     ):
         """Remove a resource provider."""
-        from llmling_agent.resource_providers.base import ResourceProvider
+        from llmling_agent.resource_providers import ResourceProvider
 
         match provider:
             case ResourceProvider():
@@ -218,7 +221,9 @@ class ToolManager(BaseRegistry[str, Tool]):
 
             for provider, result in zip(self.providers, results, strict=False):
                 if isinstance(result, BaseException):
-                    logger.exception("Failed to get tools from provider: %r", provider)
+                    logger.exception(
+                        "Failed to get tools from provider", provider=provider
+                    )
                     continue
                 tools.extend(t for t in result if t.matches_filter(state))
         # Sort by priority if any have non-default priority
@@ -247,91 +252,29 @@ class ToolManager(BaseRegistry[str, Tool]):
         """Get tool names based on state."""
         return {t.name for t in await self.get_tools() if t.matches_filter(state)}
 
-    async def list_prompts(self) -> list[dict[str, Any]]:
-        """Get all MCP prompt metadata from all providers.
+    async def list_prompts(self) -> list[Prompt]:
+        """Get all prompts from all providers.
 
         Returns:
-            List of prompt metadata dictionaries with name, description, and arguments
+            List of Prompt instances
         """
         from llmling_agent.mcp_server.manager import MCPManager
 
-        all_prompts = []
+        all_prompts: list[Prompt] = []
 
-        # Get raw MCP prompt metadata from all providers
+        # Get prompts from all MCP providers
         for provider in self.providers:
             if isinstance(provider, MCPManager):
                 try:
-                    # Get raw MCP prompt metadata from all clients
-                    for client in provider.clients.values():
-                        try:
-                            result = await client.list_prompts()
-                            # Convert raw MCP prompts to dict format
-                            for mcp_prompt in result:
-                                prompt_dict = {
-                                    "name": mcp_prompt.name,
-                                    "description": mcp_prompt.description,
-                                    "arguments": [
-                                        {
-                                            "name": arg.name,
-                                            "description": arg.description,
-                                            "required": arg.required,
-                                        }
-                                        for arg in mcp_prompt.arguments
-                                    ]
-                                    if mcp_prompt.arguments
-                                    else [],
-                                }
-                                all_prompts.append(prompt_dict)
-                        except Exception:
-                            logger.exception("Failed to list prompts from MCP client")
-                            continue
+                    prompts = await provider.list_prompts()
+                    all_prompts.extend(prompts)
                 except Exception:
-                    logger.exception("Failed to get prompts from provider: %r", provider)
+                    logger.exception(
+                        "Failed to get prompts from provider", provider=provider
+                    )
 
         return all_prompts
 
-    async def get_resolved_prompt(
-        self, name: str, arguments: dict[str, Any] | None = None
-    ) -> str | None:
-        """Get a resolved prompt by name with optional arguments.
-
-        Args:
-            name: Name of the prompt to retrieve
-            arguments: Optional arguments to pass to the prompt
-
-        Returns:
-            Resolved prompt content as string if found, None otherwise
-        """
-        from llmling_agent.mcp_server.manager import MCPManager
-
-        # Search through all MCP providers
-        for provider in self.providers:
-            if isinstance(provider, MCPManager):
-                try:
-                    # Check each client in the MCP manager
-                    for client in provider.clients.values():
-                        try:
-                            # Try to get the resolved prompt from this client
-                            result = await client.get_prompt(name, arguments)
-                            # Convert MCP response messages to string content
-                            from mcp.types import TextContent
-
-                            content_parts = []
-                            for message in result.messages:
-                                if isinstance(message.content, TextContent):
-                                    content_parts.append(message.content.text)
-                                elif isinstance(message.content, str):
-                                    content_parts.append(message.content)
-                            return "\n".join(content_parts) if content_parts else None
-                        except Exception:  # noqa: BLE001
-                            # This client doesn't have the prompt, try next
-                            continue
-                except Exception:
-                    logger.exception("Failed to get prompt from provider: %r", provider)
-                    continue
-
-        return None
-
     def register_tool(
         self,
         tool: ToolType | Tool,
@@ -339,7 +282,7 @@ class ToolManager(BaseRegistry[str, Tool]):
         name_override: str | None = None,
         description_override: str | None = None,
         enabled: bool = True,
-        source: ToolSource = "runtime",
+        source: ToolSource = "dynamic",
         priority: int = 100,
         requires_confirmation: bool = False,
         requires_capability: str | None = None,
@@ -348,7 +291,7 @@ class ToolManager(BaseRegistry[str, Tool]):
         """Register a new tool with custom settings.
 
         Args:
-            tool: Tool to register (callable, LLMCallableTool, or import path)
+            tool: Tool to register (callable, or import path)
             enabled: Whether tool is initially enabled
             name_override: Optional name override for the tool
             description_override: Optional description override for the tool
@@ -363,36 +306,28 @@ class ToolManager(BaseRegistry[str, Tool]):
         """
         # First convert to basic Tool
         match tool:
-            case LLMCallableTool():
-                llm_tool = tool
-                llm_tool.name = name_override or llm_tool.name
-                llm_tool.description = description_override or llm_tool.description
             case Tool():
-                llm_tool = tool.callable
-                llm_tool.description = description_override or llm_tool.description
-                llm_tool.name = name_override or llm_tool.name
+                tool.description = description_override or tool.description
+                tool.name = name_override or tool.name
+                tool.source = source
+                tool.metadata = tool.metadata | (metadata or {})
+
             case _:
-                llm_tool = LLMCallableTool.from_callable(
+                tool = Tool.from_callable(
                     tool,
+                    enabled=enabled,
+                    source=source,
                     name_override=name_override,
                     description_override=description_override,
+                    priority=priority,
+                    requires_confirmation=requires_confirmation,
+                    requires_capability=requires_capability,
+                    metadata=metadata or {},
                 )
 
-        if llm_tool.description and len(llm_tool.description) > MAX_LEN_DESCRIPTION:
-            msg = f"Too long description for {tool}"
-            raise ToolError(msg)
-        tool_info = Tool(
-            llm_tool,
-            enabled=enabled,
-            source=source,
-            priority=priority,
-            requires_confirmation=requires_confirmation,
-            requires_capability=requires_capability,
-            metadata=metadata or {},
-        )
         # Register the tool
-        self.register(tool_info.name, tool_info)
-        return tool_info
+        self.register(tool.name, tool)
+        return tool
 
     def register_worker(
         self,
@@ -502,7 +437,7 @@ class ToolManager(BaseRegistry[str, Tool]):
         *,
         description: str | None = None,
         enabled: bool = True,
-        source: ToolSource = "runtime",
+        source: ToolSource = "dynamic",
         priority: int = 100,
         requires_confirmation: bool = False,
         requires_capability: str | None = None,
