@@ -16,10 +16,10 @@ def to_type(
     output_type, responses: dict[str, StructuredResponseConfig] | None = None
 ) -> type[BaseModel | str]:
     match output_type:
+        case str() if responses and output_type in responses:
+            defn = responses[output_type]  # from defined responses
+            return defn.response_schema.get_schema()
         case str():
-            if responses and output_type in responses:
-                defn = responses[output_type]  # from defined responses
-                return defn.response_schema.get_schema()
             msg = f"Missing responses dict for response type: {output_type!r}"
             raise ValueError(msg)
         case InlineSchemaDef():
