@@ -3,68 +3,14 @@
 from __future__ import annotations
 
 from slashed import CommandContext, CommandError, SlashedCommand  # noqa: TC002
-from slashed.completers import CallbackCompleter
 
 from llmling_agent.agent.context import AgentContext  # noqa: TC001
 from llmling_agent.log import get_logger
-from llmling_agent_commands.completers import get_resource_names
 from llmling_agent_commands.markdown_utils import format_table
 
 
 logger = get_logger(__name__)
 
-LIST_RESOURCES_HELP = """\
-Display all resources available to the agent.
-
-Shows:
-- Resource names and descriptions
-- Resource types and URIs
-- Whether parameters are supported
-- MIME types
-
-Resource types can be:
-- path: Files or URLs
-- text: Raw text content
-- cli: Command line tools
-- source: Python source code
-- callable: Python functions
-- image: Image files
-
-Use /show-resource for detailed information about specific resources.
-"""
-
-SHOW_RESOURCES_HELP = """\
-Display detailed information and content of a specific resource.
-
-Shows:
-- Resource metadata (type, URI, description)
-- MIME type information
-- Parameter support status
-- Resource content (if loadable)
-
-For resources that support parameters:
-- Pass parameters as --param arguments
-- Parameters are passed to resource loader\
-
-Examples:
-  /show-resource config.yml               # Show configuration file
-  /show-resource template --date today    # Template with parameters
-  /show-resource image.png               # Show image details
-  /show-resource api --key value         # API with parameters
-
-Note: Some resources might require parameters to be viewed.
-"""
-
-ADD_RESOURCE_HELP = """\
-Add content from a resource to the next message.
-
-Parameters are passed to the resource loader if supported.
-
-Examples:
-/add-resource config.yml
-/add-resource template --date today
-/add-resource api_data --key value"""
-
 
 class ListResourcesCommand(SlashedCommand):
     """Display all resources available to the agent.
@@ -188,10 +134,6 @@ class ShowResourceCommand(SlashedCommand):
         except Exception as e:  # noqa: BLE001
             await ctx.print(f"❌ **Error accessing resource:** {e}")
 
-    def get_completer(self):
-        """Get completer for resource names."""
-        return CallbackCompleter(get_resource_names)
-
 
 class AddResourceCommand(SlashedCommand):
     """Add content from a resource to the next message.
@@ -264,7 +206,3 @@ class AddResourceCommand(SlashedCommand):
             msg = f"Error loading resource: {e}"
             logger.exception(msg)
             raise CommandError(msg) from e
-
-    def get_completer(self):
-        """Get completer for resource names."""
-        return CallbackCompleter(get_resource_names)
