@@ -25,19 +25,6 @@ class PromptLayerConfig(BasePromptHubConfig):
     """API key for the PromptLayer API."""
 
 
-class OpenLITConfig(BasePromptHubConfig):
-    """Configuration for OpenLIT prompt provider."""
-
-    type: Literal["openlit"] = Field("openlit", init=False)
-    """Configuration for OpenLIT prompt provider."""
-
-    url: HttpUrl | None = None  # Optional, defaults to OPENLIT_URL env var
-    """URL of the OpenLIT API."""
-
-    api_key: SecretStr | None = None  # Optional, defaults to OPENLIT_API_KEY env var
-    """API key for the OpenLIT API."""
-
-
 class LangfuseConfig(BasePromptHubConfig):
     """Configuration for Langfuse prompt provider."""
 
@@ -63,16 +50,6 @@ class LangfuseConfig(BasePromptHubConfig):
     """Timeout for fetching responses in seconds."""
 
 
-class TraceloopConfig(BasePromptHubConfig):
-    """Configuration for Traceloop prompt provider."""
-
-    type: Literal["traceloop"] = Field("traceloop", init=False)
-    """Configuration for Traceloop prompt provider."""
-
-    api_key: SecretStr | None = None  # Optional, defaults to TRACELOOP_API_KEY env var
-    """API key for the Traceloop API."""
-
-
 class BraintrustConfig(BasePromptHubConfig):
     """Configuration for Braintrust prompt provider."""
 
@@ -94,11 +71,6 @@ class FabricConfig(BasePromptHubConfig):
 
 
 PromptHubConfig = Annotated[
-    PromptLayerConfig
-    | OpenLITConfig
-    | LangfuseConfig
-    | TraceloopConfig
-    | FabricConfig
-    | BraintrustConfig,
+    PromptLayerConfig | LangfuseConfig | FabricConfig | BraintrustConfig,
     Field(discriminator="type"),
 ]
