@@ -116,12 +116,6 @@ def _(page: mk.MkPage):
     page += mk.MkTemplate("docs/config_file/task_config.md")
 
 
-@nav.route.page("Environment Setup", icon="octicon:tools-16")
-def _(page: mk.MkPage):
-    """Environment configuration for tools and resources."""
-    page += mk.MkTemplate("docs/config_file/env_config.md")
-
-
 @nav.route.page("Inheritance", icon="octicon:git-merge-16")
 def _(page: mk.MkPage):
     """Configuration inheritance system."""
