@@ -18,7 +18,7 @@ if TYPE_CHECKING:
     from pydantic_ai import FinishReason
 
     from llmling_agent.common_types import JsonValue
-    from llmling_agent.messaging.messages import ChatMessage, TokenCost
+    from llmling_agent.messaging import ChatMessage, TokenCost
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.storage import BaseStorageProviderConfig
     from llmling_agent_storage.models import ConversationData, QueryFilters, StatsFilters
@@ -104,7 +104,7 @@ class StorageProvider[T]:
         forwarded_from: list[str] | None = None,
         provider_name: str | None = None,
         provider_response_id: str | None = None,
-        parts: str | None = None,
+        messages: str | None = None,
         finish_reason: FinishReason | None = None,
     ):
         """Log a message (if supported)."""
@@ -165,7 +165,7 @@ class StorageProvider[T]:
             model=model,
             provider_name=None,
             provider_response_id=None,
-            parts=None,
+            messages=None,
             finish_reason=None,
         )
 
