@@ -167,8 +167,8 @@ class Message(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
     provider_response_id: str | None = None
     """Request ID as specified by the model provider"""
 
-    parts: str | None = None
-    """Serialized pydantic-ai message parts"""
+    messages: str | None = None
+    """Serialized pydantic-ai model messages"""
 
     finish_reason: str | None = None  # Literal pydantic_ai.FinishReason
     """Reason the model finished generating the response"""
@@ -188,6 +188,9 @@ class Conversation(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
     agent_name: str = Field(index=True)
     """Name of the agent handling the conversation"""
 
+    title: str | None = Field(default=None, index=True)
+    """Generated title for the conversation"""
+
     start_time: datetime = Field(
         sa_column=Column(UTCDateTime, index=True), default_factory=get_now
     )
