@@ -6,7 +6,7 @@ import os
 from typing import Any
 
 from llmling_agent.log import get_logger
-from llmling_agent.resource_providers.base import ResourceProvider
+from llmling_agent.resource_providers import ResourceProvider
 from llmling_agent.tools.base import Tool
 
 
