@@ -5,9 +5,7 @@ from __future__ import annotations
 import os
 from typing import TYPE_CHECKING
 
-from llmling.core.log import get_logger
-
-from llmling_agent.resource_providers.base import ResourceProvider
+from llmling_agent.resource_providers import ResourceProvider
 
 
 if TYPE_CHECKING:
@@ -16,9 +14,6 @@ if TYPE_CHECKING:
     from llmling_agent.tools.base import Tool
 
 
-logger = get_logger(__name__)
-
-
 class UpsonicTools(ResourceProvider):
     """Provider for upsonic tools."""
 
